@@ -86,35 +86,16 @@ def get_configure_commands(source: pathlib.Path, destination: pathlib.Path,
 
         else:
 
-            raise Exception(f"Visual Studio not found")        
-
-    elif platform.system() == "Linux":
-
-        os_configure_args += ["-DWITH_AUDASPACE=OFF"]
-
-        if distro.linux_distribution()[0].casefold() in ["debian", "raspbian"]:
-
-            # JEMALLOC breaks the import on debian-based linux distributions
-
-            os_configure_args += ["-DWITH_MEM_JEMALLOC=OFF"]
+            raise Exception(f"Visual Studio not found")
 
     elif platform.system() == "Darwin":
 
         os_configure_args += ["-DWITH_OPENMP=OFF", "-DWITH_AUDASPACE=OFF"]
 
-    if platform.system() != "Windows":
-
-        commands.append(["make", "-C", str(source.absolute()), "update"])
-
-    if platform.system() == "Linux"and distro.linux_distribution()[0].casefold() != "centos":
-
-        commands.append([os.path.join(str(source.absolute()), 
-                         "build_files", "build_environment", 
-                         "install_deps.sh")])
-
     commands.append(['cmake',
                      '-DWITH_PLAYER=OFF', '-DWITH_PYTHON_INSTALL=OFF',
-                     '-DWITH_PYTHON_MODULE=ON', 
+                     '-DWITH_PYTHON_MODULE=ON', "-DWITH_MEM_JEMALLOC=OFF",
+                     "-DWITH_OPENMP_STATIC=OFF",
                      f"-DPYTHON_VERSION={sys.version_info[0]}."
                      f"{sys.version_info[1]}", 
                      "-DWITH_CYCLES_CUDA_BINARIES=ON" if with_cuda else "",
